<?php
/**
 * Directory Gadget
 *
 * @category    Gadget
 * @package     Directory
 */
class Directory_Actions_Directory extends Jaws_Gadget_Action
{
    /**
     * Get Display action params
     *
     * @access  public
     * @return  array list of Display action params
     */
    function DirectoryLayoutParams()
    {
        $result[] = array('title' => $this::t('FILE_TYPE'), 'value' =>
            array(
                0 => Jaws::t('ALL'),
                Directory_Info::FILE_TYPE_FOLDER  => $this::t('FILE_TYPE_FOLDER'),
                Directory_Info::FILE_TYPE_TEXT    => $this::t('FILE_TYPE_TEXT'),
                Directory_Info::FILE_TYPE_IMAGE   => $this::t('FILE_TYPE_IMAGE'),
                Directory_Info::FILE_TYPE_AUDIO   => $this::t('FILE_TYPE_AUDIO'),
                Directory_Info::FILE_TYPE_VIDEO   => $this::t('FILE_TYPE_VIDEO'),
                Directory_Info::FILE_TYPE_ARCHIVE => $this::t('FILE_TYPE_ARCHIVE'),
                Directory_Info::FILE_TYPE_UNKNOWN => $this::t('FILE_TYPE_OTHER'),
            ));

        $result[] = array(
            'title' => Jaws::t('ORDERBY'),
            'value' => array(
                1 => Jaws::t('CREATETIME') . ' &uarr;',
                2 => Jaws::t('CREATETIME') . ' &darr;',
            )
        );

        $result[] = array(
            'title' => Jaws::t('COUNT'),
            'value' =>  $this->gadget->registry->fetch('files_limit')
        );

        return $result;
    }

    /**
     * Builds directory and file navigation UI
     *
     * @param   int     $type       File type (for normal action = null)
     * @param   int     $orderBy    Order by
     * @param   int     $limit      Forms limit
     * @access  public
     * @return  string  XHTML UI
     */
    function Directory($type = null, $orderBy = 0, $limit = 0)
    {
        $id = ($type == null)? (int)$this->gadget->request->fetch('id') : 0;
        if (!empty($id)) {
            $file = $this->gadget->model->load('Files')->GetFile($id);
            if (Jaws_Error::IsError($file) || empty($file) || !$file['is_dir']) {
                return Jaws_HTTPError::Get(404);
            }
        }

        $this->AjaxMe('index.js');
        $this->gadget->define('confirmDelete', $this::t('CONFIRM_DELETE'));

        $standalone = (bool)$this->gadget->request->fetch('standalone');
        if ($standalone) {
            $this->SetActionMode('Directory', 'standalone', 'normal');
        }

        $tpl = $this->gadget->template->load('Directory.html');
        $tpl->SetBlock('directory');

        $response = $this->gadget->session->pop('SaveFile');
        if (!empty($response)) {
            $tpl->SetVariable('response_type', $response['type']);
            $tpl->SetVariable('response_text', $response['text']);
        }

        $this->title = $this::t('ACTIONS_DIRECTORY');
        $tpl->SetVariable('title', $this::t('ACTIONS_DIRECTORY'));

        // parse files, filters, pagination
        $this->ListFiles($tpl, $id, $type, $orderBy, $limit);

        $tpl->SetVariable('root', $this::t('HOME'));
        $tpl->SetVariable('root_url', $this->gadget->urlMap('Directory'));
        $tpl->SetVariable('path', $this->GetPath($id));

        if ($this->gadget->GetPermission('UploadFiles')) {
            $tpl->SetBlock('directory/upload_files');
            $tpl->SetVariable('upload', $this::t('UPLOAD_FILE'));
            $tpl->ParseBlock('directory/upload_files');
        }

        // if user has permission, display upload area
        if ($this->app->session->user->logged) {
            $tpl->SetBlock('directory/upload_form');
            $tpl->SetVariable('lbl_file', $this::t('FILE'));
            $tpl->SetVariable('lbl_thumbnail', $this::t('THUMBNAIL'));
            $tpl->SetVariable('lbl_title', $this::t('FILE_TITLE'));
            $tpl->SetVariable('lbl_desc', $this::t('FILE_DESC'));
            $tpl->SetVariable('lbl_tags', $this::t('FILE_TAGS'));
            $tpl->SetVariable('lbl_public', $this::t('FILE_PUBLIC'));
            $tpl->SetVariable('lbl_url', $this::t('FILE_URL'));
            $tpl->SetVariable('lbl_cancel', Jaws::t('CANCEL'));
            $tpl->SetVariable('lbl_ok', Jaws::t('OK'));

            $description = '';
            $descriptionEditor =& $this->app->loadEditor(
                'Directory', 'description', Jaws_XSS::defilter($description), false
            );
            $descriptionEditor->setId('description');
            $descriptionEditor->TextArea->SetRows(8);
            $tpl->SetVariable('description', $descriptionEditor->Get());

            $tpl->SetVariable('parent', $id);
            $tpl->SetVariable('referrer', bin2hex(Jaws_Utils::getRequestURL(true)));
            if ($this->gadget->GetPermission('PublishFiles')) {
                $tpl->SetBlock('directory/upload_form/published');
                $tpl->SetVariable('lbl_published', Jaws::t('PUBLISHED'));
                if (isset($fileInfo['published']) && $fileInfo['published']) {
                    $tpl->SetVariable('published_checked', 'checked');
                }
                $tpl->ParseBlock('directory/upload_form/published');
            }

            $tpl->SetVariable('root', $this::t('HOME'));
            $tpl->SetVariable('root_url', $this->gadget->urlMap('Directory'));

            $tpl->ParseBlock('directory/upload_form');
        }

        $tpl->ParseBlock('directory');

        if ($this->app->requestedActionMode == ACTION_MODE_NORMAL) {
            return $tpl->Get();
        } else {
            $assigns = $this->xListFiles();
            return $this->gadget->template->xLoad('DirBox.html')->render($assigns);
        }

    }

    /**
     * Fetches and displays list of directories/files
     *
     * @access  public
     * @param   int     $parent
     * @param   null    $type
     * @param   int     $orderBy    Order by
     * @param   int     $limit      Forms limit
     * @return string HTML content
     */
    function ListFiles(&$tpl, $parent = 0, $type = null, $orderBy = 0, $limit = 0)
    {
        $params = array();
        $filters = $this->gadget->request->fetch(
            array('filter_file_type', 'filter_file_size', 'filter_from_date', 'filter_to_date', 'filter_order'),
            'post'
        );

        // Layout action
        $isLayoutAction = $this->app->requestedActionMode == ACTION_MODE_LAYOUT;
        if ($isLayoutAction) {
            $page = 0;
            $params['file_type'] = (int)$type;
            if ($params['file_type'] == 1) {
                $params['is_dir'] = true;
            }
        } else {
            $get = $this->gadget->request->fetch(array('type', 'order', 'page'), 'get');
            $page = (int)$get['page'];
            $params['file_type'] = (int)$get['type'];
            if (!empty($get['order'])) {
                $orderBy = (int)$get['order'];
            }
        }

        $params['limit']  = ($limit > 0) ? $limit : (int)$this->gadget->registry->fetch('items_per_page');
        $params['offset'] = ($page == 0)? 0 : $params['limit'] * ($page - 1);
        $params['parent'] = (int)$parent;
        $params['public'] = true;
        $params['published'] = true;

        $user = $this->gadget->request->fetch('user', 'get');
        if (!empty($user)) {
            if (is_numeric($user)) {
                $params['user'] = (int)$user;
                if ($params['user'] == (int)$this->app->session->user->id) {
                    unset($params['public'], $params['published']);
                }
            } else {
                $params['user'] = $user;
                if ($params['user'] == $this->app->session->user->username) {
                    unset($params['public'], $params['published']);
                }
            }

        }

        // check filters
        if (!is_null($filters['filter_file_type'])) {
            $params['file_type'] = $filters['filter_file_type'];
            if ($filters['filter_file_type'] == 1) {
                $params['is_dir'] = true;
            }
        }
        if (!empty($filters['filter_file_size'])) {
            $params['file_size'] = ($filters['filter_file_size'] == '0') ?
                null : explode(',', $filters['filter_file_size']);
        }

        $jdate = Jaws_Date::getInstance();
        $from_date = $to_date = '';
        if (!empty($filters['filter_from_date'])) {
            $from_date = $jdate->ToBaseDate(preg_split('/[- :]/', $filters['filter_from_date']));
            $from_date = $this->app->UserTime2UTC($from_date['timestamp']);
        }
        if (!empty($filters['filter_to_date'])) {
            $to_date = $jdate->ToBaseDate(preg_split('/[- :]/', $filters['filter_to_date'] . ' 23:59:59'));
            $to_date = $this->app->UserTime2UTC($to_date['timestamp']);
        }
        $params['date'] = array($from_date, $to_date);
        if (!empty($filters['filter_order'])) {
            $orderBy = (int)$filters['filter_order'];
        }

        $calType = strtolower($this->gadget->registry->fetch('calendar', 'Settings'));
        $calLang = strtolower($this->gadget->registry->fetch('admin_language', 'Settings'));
        if ($calType != 'gregorian') {
            $this->app->layout->addScript("libraries/piwi/piwidata/js/jscalendar/$calType.js");
        }
        $this->app->layout->addScript('libraries/piwi/piwidata/js/jscalendar/calendar.js');
        $this->app->layout->addScript('libraries/piwi/piwidata/js/jscalendar/calendar-setup.js');
        $this->app->layout->addScript("libraries/piwi/piwidata/js/jscalendar/lang/calendar-$calLang.js");
        $this->app->layout->addLink('libraries/piwi/piwidata/js/jscalendar/calendar-blue.css');
        $this->AjaxMe('index.js');

        $block = $tpl->GetCurrentBlockPath();
        $tpl->SetBlock("$block/filters");

        $tpl->SetVariable('lbl_type', $this::t('FILE_TYPE'));
        $tpl->SetVariable('lbl_size', $this::t('FILE_SIZE'));
        $tpl->SetVariable('lbl_from_date', $this::t('FILE_FROM_DATE'));
        $tpl->SetVariable('lbl_to_date', $this::t('FILE_TO_DATE'));
        $tpl->SetVariable('lbl_search', Jaws::t('SEARCH'));
        $tpl->SetVariable('lbl_order', Jaws::t('ORDERBY'));
        $tpl->SetVariable('lbl_create_time', Jaws::t('CREATETIME'));

        $tpl->SetVariable('lbl_folder', $this::t('FILE_TYPE_FOLDER'));
        $tpl->SetVariable('lbl_text', $this::t('FILE_TYPE_TEXT'));
        $tpl->SetVariable('lbl_image', $this::t('FILE_TYPE_IMAGE'));
        $tpl->SetVariable('lbl_audio', $this::t('FILE_TYPE_AUDIO'));
        $tpl->SetVariable('lbl_video', $this::t('FILE_TYPE_VIDEO'));
        $tpl->SetVariable('lbl_archive', $this::t('FILE_TYPE_ARCHIVE'));
        $tpl->SetVariable('lbl_other', $this::t('FILE_TYPE_OTHER'));

        // file type
        $fileTypes = array();
        $fileTypes[] = array('id' => 0, 'title' => Jaws::t('ALL'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_FOLDER, 'title' => $this::t('FILE_TYPE_FOLDER'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_TEXT, 'title' => $this::t('FILE_TYPE_TEXT'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_IMAGE, 'title' => $this::t('FILE_TYPE_IMAGE'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_AUDIO, 'title' => $this::t('FILE_TYPE_AUDIO'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_VIDEO, 'title' => $this::t('FILE_TYPE_VIDEO'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_ARCHIVE, 'title' => $this::t('FILE_TYPE_ARCHIVE'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_UNKNOWN, 'title' => $this::t('FILE_TYPE_OTHER'));
        foreach ($fileTypes as $fileType) {
            $tpl->SetBlock("$block/filters/file_type");
            $tpl->SetVariable('value', $fileType['id']);
            $tpl->SetVariable('title', $fileType['title']);

            $tpl->SetVariable('selected', '');
            if (isset($params['file_type']) && $params['file_type'] == $fileType['id']) {
                $tpl->SetVariable('selected', 'selected');
            }
            $tpl->ParseBlock("$block/filters/file_type");
        }

        // file size
        $fileSizes = array();
        $fileSizes[] = array('id' => '0', 'title' => Jaws::t('ALL'));
        $fileSizes[] = array('id' => '0,10', 'title' => '0 - 10 KB');
        $fileSizes[] = array('id' => '10,100', 'title' => '10 - 100 KB');
        $fileSizes[] = array('id' => '100,1024', 'title' => '100 KB - 1 MB');
        $fileSizes[] = array('id' => '1024,16384', 'title' => '1 MB - 16 MB');
        $fileSizes[] = array('id' => '16384,131072', 'title' => '16 MB - 128 MB');
        $fileSizes[] = array('id' => '131072,', 'title' => '>> 128 MB');
        foreach($fileSizes as $fileSize) {
            $tpl->SetBlock("$block/filters/file_size");
            $tpl->SetVariable('value', $fileSize['id']);
            $tpl->SetVariable('title', $fileSize['title']);

            $tpl->SetVariable('selected', '');
            if ($filters['filter_file_size'] == $fileSize['id']) {
                $tpl->SetVariable('selected', 'selected');
            }
            $tpl->ParseBlock("$block/filters/file_size");
        }

        // Start date
        $cal_type = $this->gadget->registry->fetch('calendar', 'Settings');
        $cal_lang = $this->gadget->registry->fetch('site_language', 'Settings');
        $datePicker =& Piwi::CreateWidget('DatePicker', 'filter_from_date', $filters['filter_from_date']);
        $datePicker->setCalType($cal_type);
        $datePicker->setLanguageCode($cal_lang);
        $datePicker->setDateFormat('%Y-%m-%d');
        $datePicker->setStyle('width:80px');
        $tpl->SetVariable('from_date', $datePicker->Get());

        // End date
        $datePicker =& Piwi::CreateWidget('DatePicker', 'filter_to_date', $filters['filter_to_date']);
        $datePicker->setDateFormat('%Y-%m-%d');
        $datePicker->setCalType($cal_type);
        $datePicker->setLanguageCode($cal_lang);
        $datePicker->setStyle('width:80px');
        $tpl->SetVariable('to_date', $datePicker->Get());

        $tpl->SetVariable('order_selected_' . $orderBy, 'selected');
        $tpl->ParseBlock("$block/filters");

        $tpl->SetBlock("$block/files");
        $model = $this->gadget->model->load('Files');
        $files = $model->GetFiles($params, false, $orderBy);
        if (Jaws_Error::IsError($files)) {
            return;
        }
        if (empty($files)) {
            $tpl->SetBlock("$block/files/message");
            $tpl->SetVariable('msg', $this::t('INFO_NO_FILES'));
            $tpl->ParseBlock("$block/files/message");
            return;
        }
        $count = $model->GetFiles($params, true, $orderBy);

        $tpl->SetVariable('lbl_title', $this::t('FILE_TITLE'));
        $tpl->SetVariable('lbl_created', $this::t('FILE_CREATED'));
        $tpl->SetVariable('lbl_modified', $this::t('FILE_MODIFIED'));
        $tpl->SetVariable('lbl_type', $this::t('FILE_TYPE'));
        $tpl->SetVariable('lbl_size', $this::t('FILE_SIZE'));
        $tpl->SetVariable('lbl_action', Jaws::t('ACTIONS'));

        $tpl->SetVariable('site_url', $this->app->getSiteURL('/'));
        $theme = $this->app->GetTheme();
        $iconUrl = is_dir($theme['url'] . 'mimetypes')? $theme['url'] . 'mimetypes/' : 'images/mimetypes/';
        $icons = array(
            1 => 'folder',
            2 => 'text-generic',
            3 => 'image-generic',
            4 => 'audio-generic',
            5 => 'video-generic',
            6 => 'package-generic',
            99 => 'file-generic',
        );
        $objDate = Jaws_Date::getInstance();
        foreach ($files as $file) {
            if ($file['is_dir']) {
                $url = $this->gadget->urlMap('Directory', array('id' => $file['id']));
            } else {
                $url = $this->gadget->urlMap('File', array('id' => $file['id']));
            }
            $tpl->SetBlock("$block/files/file");
            $tpl->SetVariable('url', $url);
            $tpl->SetVariable('id', $file['id']);
            $tpl->SetVariable('title', $file['title']);
            $tpl->SetVariable('description', $file['description']);
            $tpl->SetVariable('type', empty($file['mime_type'])? '-' : $file['mime_type']);
            $tpl->SetVariable('size', Jaws_Utils::FormatSize($file['file_size']));
            $tpl->SetVariable('created', $objDate->Format($file['create_time'], 'MM/dd/yyyy hh:mm aa'));
            $tpl->SetVariable('modified', $objDate->Format($file['update_time'], 'MM/dd/yyyy hh:mm aa'));

            if (!$file['public']) {
                $tpl->SetBlock("$block/files/file/action");
                $tpl->SetVariable('lbl_delete', Jaws::t('DELETE'));
                $tpl->SetVariable('id', $file['id']);
                $tpl->SetVariable('lbl_edit', Jaws::t('EDIT'));
                $tpl->SetVariable('id',  $file['id']);
                $tpl->SetVariable('parent',  $parent);
                $tpl->ParseBlock("$block/files/file/action");
            }

            $thumbnailURL = $model->GetThumbnailURL($file['host_filename']);
            if (!empty($thumbnailURL)) {
                $tpl->SetVariable('icon', $thumbnailURL);
            } else {
                $tpl->SetVariable('icon', $iconUrl . $icons[$file['file_type']] . '.png');
            }

            // display file
            $tpl->SetVariable(
                'preview',
                $this->gadget->action->loadAdmin('Files')->PlayMedia($file)
            );

            $tpl->ParseBlock("$block/files/file");
        }

        // Pagination
        if (!$isLayoutAction && $params['limit'] > 0) {
            $args = array();
            if ($parent > 0) {
                $args['id'] = $parent;
            }
            if (!empty($params['user'])) {
                $args['user'] = $params['user'];
            }
            if (!empty($params['public'])) {
                $args['public'] = (int)$params['public'];
            }
            if (!empty($params['file_type'])) {
                $args['type'] = $params['file_type'];
            }
            if (!empty($orderBy)) {
                $args['order'] = $orderBy;
            }

            $this->gadget->action->load('PageNavigation')->pagination(
                $tpl,
                $page,
                $params['limit'],
                $count,
                'Directory',
                $args
            );
        }

        $tpl->ParseBlock("$block/files");
        return;
    }

    /**
     * Fetches and displays list of directories/files
     *
     * @access  public
     * @param   int     $parent
     * @param   null    $type
     * @param   int     $orderBy    Order by
     * @param   int     $limit      Forms limit
     * @return string HTML content
     */
    function xListFiles($parent = 0, $type = null, $orderBy = 0, $limit = 0)
    {
        $assigns = array();

        $params = array();
        $filters = $this->gadget->request->fetch(
            array('filter_file_type', 'filter_file_size', 'filter_from_date', 'filter_to_date', 'filter_order'),
            'post'
        );

        // Layout action
        $isLayoutAction = $this->app->requestedActionMode == ACTION_MODE_LAYOUT;
        if ($isLayoutAction) {
            $page = 0;
            $params['file_type'] = (int)$type;
            if ($params['file_type'] == 1) {
                $params['is_dir'] = true;
            }
        } else {
            $get = $this->gadget->request->fetch(array('type', 'order', 'page'), 'get');
            $page = (int)$get['page'];
            $params['file_type'] = (int)$get['type'];
            if (!empty($get['order'])) {
                $orderBy = (int)$get['order'];
            }
        }

        $params['limit']  = ($limit > 0) ? $limit : (int)$this->gadget->registry->fetch('items_per_page');
        $params['offset'] = ($page == 0)? 0 : $params['limit'] * ($page - 1);
        $params['parent'] = (int)$parent;
        $params['public'] = true;
        $params['published'] = true;

        $user = $this->gadget->request->fetch('user', 'get');
        if (!empty($user)) {
            if (is_numeric($user)) {
                $params['user'] = (int)$user;
                if ($params['user'] == (int)$this->app->session->user->id) {
                    unset($params['public'], $params['published']);
                }
            } else {
                $params['user'] = $user;
                if ($params['user'] == $this->app->session->user->username) {
                    unset($params['public'], $params['published']);
                }
            }
        }

        // check filters
        if (!is_null($filters['filter_file_type'])) {
            $params['file_type'] = $filters['filter_file_type'];
            if ($filters['filter_file_type'] == 1) {
                $params['is_dir'] = true;
            }
        }
        if (!empty($filters['filter_file_size'])) {
            $params['file_size'] = ($filters['filter_file_size'] == '0') ?
                null : explode(',', $filters['filter_file_size']);
        }

        $jdate = Jaws_Date::getInstance();
        $from_date = $to_date = '';
        if (!empty($filters['filter_from_date'])) {
            $from_date = $jdate->ToBaseDate(preg_split('/[- :]/', $filters['filter_from_date']));
            $from_date = $this->app->UserTime2UTC($from_date['timestamp']);
        }
        if (!empty($filters['filter_to_date'])) {
            $to_date = $jdate->ToBaseDate(preg_split('/[- :]/', $filters['filter_to_date'] . ' 23:59:59'));
            $to_date = $this->app->UserTime2UTC($to_date['timestamp']);
        }
        $params['date'] = array($from_date, $to_date);
        if (!empty($filters['filter_order'])) {
            $orderBy = (int)$filters['filter_order'];
        }

        $calType = strtolower($this->gadget->registry->fetch('calendar', 'Settings'));
        $calLang = strtolower($this->gadget->registry->fetch('admin_language', 'Settings'));
        if ($calType != 'gregorian') {
            $this->app->layout->addScript("libraries/piwi/piwidata/js/jscalendar/$calType.js");
        }
        $this->app->layout->addScript('libraries/piwi/piwidata/js/jscalendar/calendar.js');
        $this->app->layout->addScript('libraries/piwi/piwidata/js/jscalendar/calendar-setup.js');
        $this->app->layout->addScript("libraries/piwi/piwidata/js/jscalendar/lang/calendar-$calLang.js");
        $this->app->layout->addLink('libraries/piwi/piwidata/js/jscalendar/calendar-blue.css');
        $this->AjaxMe('index.js');

        // file type
        $fileTypes = array();
        $fileTypes[] = array('id' => 0, 'title' => Jaws::t('ALL'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_FOLDER, 'title' => $this::t('FILE_TYPE_FOLDER'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_TEXT, 'title' => $this::t('FILE_TYPE_TEXT'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_IMAGE, 'title' => $this::t('FILE_TYPE_IMAGE'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_AUDIO, 'title' => $this::t('FILE_TYPE_AUDIO'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_VIDEO, 'title' => $this::t('FILE_TYPE_VIDEO'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_ARCHIVE, 'title' => $this::t('FILE_TYPE_ARCHIVE'));
        $fileTypes[] = array('id' => Directory_Info::FILE_TYPE_UNKNOWN, 'title' => $this::t('FILE_TYPE_OTHER'));
        $assigns['file_types'] = $fileTypes;

        // file size
        $fileSizes = array();
        $fileSizes[] = array('id' => '0', 'title' => Jaws::t('ALL'));
        $fileSizes[] = array('id' => '0,10', 'title' => '0 - 10 KB');
        $fileSizes[] = array('id' => '10,100', 'title' => '10 - 100 KB');
        $fileSizes[] = array('id' => '100,1024', 'title' => '100 KB - 1 MB');
        $fileSizes[] = array('id' => '1024,16384', 'title' => '1 MB - 16 MB');
        $fileSizes[] = array('id' => '16384,131072', 'title' => '16 MB - 128 MB');
        $fileSizes[] = array('id' => '131072,', 'title' => '>> 128 MB');
        $assigns['file_sizes'] = $fileSizes;

        $model = $this->gadget->model->load('Files');
        $files = $model->GetFiles($params, false, $orderBy);
        if (Jaws_Error::IsError($files)) {
            return;
        }

        $theme = $this->app->GetTheme();
        $iconUrl = is_dir($theme['url'] . 'mimetypes')? $theme['url'] . 'mimetypes/' : 'images/mimetypes/';
        $assigns['icons'] = array(
            1 => 'folder',
            2 => 'text-generic',
            3 => 'image-generic',
            4 => 'audio-generic',
            5 => 'video-generic',
            6 => 'package-generic',
            99 => 'file-generic',
        );
        foreach ($files as &$file) {
            if ($file['is_dir']) {
                $file['url'] = $this->gadget->urlMap('Directory', array('id' => $file['id']));
            } else {
                $file['url'] = $this->gadget->urlMap('File', array('id' => $file['id']));
            }

            $thumbnailURL = $model->GetThumbnailURL($file['host_filename']);
            if (!empty($thumbnailURL)) {
                $file['icon'] = $thumbnailURL;
            } else {
                $file['icon'] = $iconUrl . $assigns['icons'][$file['file_type']] . '.png';
            }
        }
        $assigns['files'] = $files;

        return $assigns;
    }

    /**
     * Fetches path of a file/directory
     *
     * @access  public
     * @return  array   Directory hierarchy
     */
    function GetPath($id)
    {
        $path = '';
        $pathArr = array();
        $model = $this->gadget->model->load('Files');
        $model->GetPath($id, $pathArr);
        foreach(array_reverse($pathArr) as $i => $p) {
            $url = $this->gadget->urlMap('Directory', array('id' => $p['id']));
            $path .= ($i == count($pathArr) - 1)?
                ' > ' . $p['title'] :
                " > <a href='$url'>" . $p['title'] . '</a>';
        }
        return $path;
    }

    /**
     * Downloads(streams) file
     *
     * @access  public
     * @return  mixed   File data or Jaws_Error
     */
    function Download()
    {
        $get = $this->gadget->request->fetch(array('id', 'user', 'key'), 'get');
        $id = (int)$get['id'];
        if (empty($id)) {
            return Jaws_HTTPError::Get(404);
        }

        // Validate file
        $file = $this->gadget->model->load('Files')->GetFile($id);
        if (Jaws_Error::IsError($file) || empty($file) || empty($file['user_filename'])) {
            return Jaws_HTTPError::Get(404);
        }

        // check private file
        if (!$file['public']) {
            $loggedUser = (int)$this->app->session->user->id;
            if ($file['user'] != $loggedUser && $get['key'] != $file['key']) {
                return Jaws_HTTPError::Get(403);
            }
        }

        // Check for file existence
        $filename = ROOT_DATA_PATH . 'directory/' . $file['host_filename'];
        if (!Jaws_FileManagement_File::file_exists($filename)) {
            return Jaws_HTTPError::Get(404);
        }

        // Stream file
        if (!Jaws_FileManagement_File::download($filename, $file['user_filename'], $file['mime_type'])) {
            return Jaws_HTTPError::Get(404);
        }

        return true;
    }

}